summaryrefslogtreecommitdiff
path: root/gcc/tree-ssa-copy.c
diff options
context:
space:
mode:
authordnovillo <dnovillo@138bc75d-0d04-0410-961f-82ee72b054a4>2006-03-01 22:35:42 +0000
committerdnovillo <dnovillo@138bc75d-0d04-0410-961f-82ee72b054a4>2006-03-01 22:35:42 +0000
commiteff665b74f08f74b4d910a3797bcc4fb6c255691 (patch)
tree01a72a7a29f8e1046cda441db6c683b0feeb510d /gcc/tree-ssa-copy.c
parent0b5dc8b53229dd77c976c58b483364efd9228845 (diff)
downloadgcc-eff665b74f08f74b4d910a3797bcc4fb6c255691.tar.gz
* tree.def (SYMBOL_MEMORY_TAG): Rename from TYPE_MEMORY_TAG.
Update all users. * tree-pass.h (PROP_smt_usage): Rename from PROP_tmt_usage. Update all users. (TODO_update_smt_usage): Rename from TODO_update_tmt_usage. Update all users. * tree.h (SMT_USED_ALONE): Rename from TMT_USED_ALONE. Update all users. * tree-flow.h (struct var_ann_d): Rename field 'type_mem_tag' to 'symbol_mem_tag'. Update all users. * doc/tree-ssa.texi: Update documentation to reflect TMT->SMT rename. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@111617 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/tree-ssa-copy.c')
-rw-r--r--gcc/tree-ssa-copy.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/gcc/tree-ssa-copy.c b/gcc/tree-ssa-copy.c
index 157e8fea483..c716d118029 100644
--- a/gcc/tree-ssa-copy.c
+++ b/gcc/tree-ssa-copy.c
@@ -108,8 +108,8 @@ may_propagate_copy (tree dest, tree orig)
&& POINTER_TYPE_P (type_d)
&& POINTER_TYPE_P (type_o))
{
- tree mt_dest = var_ann (SSA_NAME_VAR (dest))->type_mem_tag;
- tree mt_orig = var_ann (SSA_NAME_VAR (orig))->type_mem_tag;
+ tree mt_dest = var_ann (SSA_NAME_VAR (dest))->symbol_mem_tag;
+ tree mt_orig = var_ann (SSA_NAME_VAR (orig))->symbol_mem_tag;
if (mt_dest && mt_orig && mt_dest != mt_orig)
return false;
else if (!lang_hooks.types_compatible_p (type_d, type_o))
@@ -187,16 +187,16 @@ merge_alias_info (tree orig, tree new)
== get_alias_set (TREE_TYPE (TREE_TYPE (orig_sym))));
#endif
- /* Synchronize the type tags. If both pointers had a tag and they
- are different, then something has gone wrong. Type tags can
+ /* Synchronize the symbol tags. If both pointers had a tag and they
+ are different, then something has gone wrong. Symbol tags can
always be merged because they are flow insensitive, all the SSA
- names of the same base DECL share the same type tag. */
- if (new_ann->type_mem_tag == NULL_TREE)
- new_ann->type_mem_tag = orig_ann->type_mem_tag;
- else if (orig_ann->type_mem_tag == NULL_TREE)
- orig_ann->type_mem_tag = new_ann->type_mem_tag;
+ names of the same base DECL share the same symbol tag. */
+ if (new_ann->symbol_mem_tag == NULL_TREE)
+ new_ann->symbol_mem_tag = orig_ann->symbol_mem_tag;
+ else if (orig_ann->symbol_mem_tag == NULL_TREE)
+ orig_ann->symbol_mem_tag = new_ann->symbol_mem_tag;
else
- gcc_assert (new_ann->type_mem_tag == orig_ann->type_mem_tag);
+ gcc_assert (new_ann->symbol_mem_tag == orig_ann->symbol_mem_tag);
/* Check that flow-sensitive information is compatible. Notice that
we may not merge flow-sensitive information here. This function